@@ -14,5 +14,5 @@
 // You should have received a copy of the GNU General Public License
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
-pub mod parameters;
-pub use parameters::*;
+pub mod parameter;
+pub use parameter::*;
